BARIS_extract: Extracting A Data frame From The French Portal data.gouv API
Description
This function read directly into R a specific data frame (resource) by the mean of its unique ID. Currently, BARIS_extract() can read directly the following types of file : json, csv, xls, xlsx, xml, geojson, and shp.
Usage
BARIS_extract(resourceId, format)
Arguments
resourceId
the unique identifier of the individual data frame (resource) to read into R. Not to confound with the global data sets ID that includes many data frames
format
the format of the required file (json, csv, xls, xlsx, xml, geojson or shp)