Learn R Programming

BARIS (version 1.1.3)

BARIS_home: Home Page Datasets

Description

This function displays the most important information about the datasets that are currently displayed within the home page of the data.gouv portal.

Usage

BARIS_home()

Arguments

Value

A dataframe with datasets characteristics

Examples

Run this code
# NOT RUN {
BARIS_home()
# }

Run the code above in your browser using DataLab