Learn R Programming

BARIS (version 1.1.3)

BARIS_resources: Displaying resources within a data set

Description

The data.gouv API provides access to several data sets in which one can find several individual data frames to exploit. The BARIS_resources lists all the data frames available within a specific data set along with the main information concerning the data frames.

Usage

BARIS_resources(datasetId)

Arguments

datasetId

the unique identifier of a data set

Value

a table of all the data frames (resources) included within a specific data set and their main characteristics

Examples

Run this code
# NOT RUN {
BARIS_resources("53699934a3a729239d2051a1")
# }

Run the code above in your browser using DataLab