Learn R Programming

BARIS (version 1.1.3)

BARIS_search: Searching for a data set

Description

This function searches specific data sets through the data.gouv API according to the pattern provided into the query argument.

Usage

BARIS_search(query, page_number = 1, page_size = 20)

Arguments

query

a character string defining the research.

page_number

numeric value denoting which page to search for, defaults to 1

page_size

numeric value, for a specific page (see page_number), how many results do you want to query. Defaults to 20

Value

a character string

Examples

Run this code
# NOT RUN {
BARIS_search("Marseille")
# }

Run the code above in your browser using DataLab