powered by
This function displays the most important information about the datasets that are currently displayed within the home page of the data.gouv portal.
BARIS_home()
A dataframe with datasets characteristics
# NOT RUN { BARIS_home() # }
Run the code above in your browser using DataLab