powered by
This function searches specific data sets through the data.gouv API according to the pattern provided into the query argument.
BARIS_search(query, page_number = 1, page_size = 20)
a character string defining the research.
numeric value denoting which page to search for, defaults to 1
numeric value, for a specific page (see page_number), how many results do you want to query. Defaults to 20
page_number
a character string
# NOT RUN { BARIS_search("Marseille") # }
Run the code above in your browser using DataLab